# Blorb

The Blorb specification was written by Andrew Plotkin as a way of providing graphics and sound resources for Z-code and Glulx games.

A Blorb file contains all the graphics and sound files needed for a game. It can also contain the Glulx code for the game as well, but does not need to: The game could also be distributed as separate Glulx and Blorb files. If you try to load a Blorb file into Windows Git that does not contain a Glulx game, it will ask you to load the appropriate Glulx file into the interpreter instead.

Blorb files can contain JPEG and PNG graphics files, AIFF sound samples, and MOD and Ogg Vorbis music files. Windows Git supports all of these formats, including transparency, opacity and gamma correction for PNG graphics.

From version 2.0, the Blorb specification also includes iFiction metadata and cover art chunks; Inform 7 can produce Blorb files containing these. If present, Windows Git uses them to determine the title of the game and to populate the About This Game dialog.

More information on Blorb is available from the Blorb web page: http://www.eblong.com/zarf/blorb/